.. _contributing.documentation.codebase:

Contributing to the Code Base
=============================

.. toctree::
   :maxdepth: 3

   contributing_code_formatting
   documenting/docstrings
   documenting/rest_guide
   contributing_deprecations
   contributing_testing_index
